==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/notepad_text_dashed.py <==
from .. import IconBase


class IconNotepadTextDashed(IconBase):
    class_name = "lucide lucide-notepad-text-dashed"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 2v4"
            }
        },
        {
            "path": {
                "d": "M12 2v4"
            }
        },
        {
            "path": {
                "d": "M16 2v4"
            }
        },
        {
            "path": {
                "d": "M16 4h2a2 2 0 0 1 2 2v2"
            }
        },
        {
            "path": {
                "d": "M20 12v2"
            }
        },
        {
            "path": {
                "d": "M20 18v2a2 2 0 0 1-2 2h-1"
            }
        },
        {
            "path": {
                "d": "M13 22h-2"
            }
        },
        {
            "path": {
                "d": "M7 22H6a2 2 0 0 1-2-2v-2"
            }
        },
        {
            "path": {
                "d": "M4 14v-2"
            }
        },
        {
            "path": {
                "d": "M4 8V6a2 2 0 0 1 2-2h2"
            }
        },
        {
            "path": {
                "d": "M8 10h6"
            }
        },
        {
            "path": {
                "d": "M8 14h8"
            }
        },
        {
            "path": {
                "d": "M8 18h5"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/notepad_text_dashed.py <==
from .. import IconBase


class IconNotepadTextDashed(IconBase):
    class_name = "lucide lucide-notepad-text-dashed"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 2v4"
            }
        },
        {
            "path": {
                "d": "M12 2v4"
            }
        },
        {
            "path": {
                "d": "M16 2v4"
            }
        },
        {
            "path": {
                "d": "M16 4h2a2 2 0 0 1 2 2v2"
            }
        },
        {
            "path": {
                "d": "M20 12v2"
            }
        },
        {
            "path": {
                "d": "M20 18v2a2 2 0 0 1-2 2h-1"
            }
        },
        {
            "path": {
                "d": "M13 22h-2"
            }
        },
        {
            "path": {
                "d": "M7 22H6a2 2 0 0 1-2-2v-2"
            }
        },
        {
            "path": {
                "d": "M4 14v-2"
            }
        },
        {
            "path": {
                "d": "M4 8V6a2 2 0 0 1 2-2h2"
            }
        },
        {
            "path": {
                "d": "M8 10h6"
            }
        },
        {
            "path": {
                "d": "M8 14h8"
            }
        },
        {
            "path": {
                "d": "M8 18h5"
            }
        }
    ]
}
